@@ -107,8 +107,9 @@ def fetch_crypto_daily_data(ssj=None, local_root_directory=None, daily_return_pk
         dataframe = pd.read_pickle(pickle_saving_path)
     return dataframe
 
-def fetch_crypto_minutely_data(ssj=None, local_root_directory=None, minutely_return_pkl_filename_suffix=None,refetch_all=True):
-    pickle_saving_path = local_root_directory + ssj + minutely_return_pkl_filename_suffix
+def fetch_crypto_minutely_data(ssj=None, local_root_directory=None, minutely_return_pkl_filename_suffix=None, running_date= None, refetch_all=True):
+    minutes_dates_stub = running_date.strftime('%d_%b_%Y')
+    pickle_saving_path = local_root_directory+ssj+'_'+minutes_dates_stub+'_'+minutely_return_pkl_filename_suffix
     if refetch_all:
         year = datetime.datetime.now().year
         month = datetime.datetime.now().month
