@@ -13,17 +13,19 @@ from sklearn import datasets, linear_model
 
 from napoleontoolbox.forecasting import lgbm_model_wrapper
 from napoleontoolbox.forecasting import arima_model_wrapper
+from napoleontoolbox.forecasting import sma_model_wrapper
 
 
 from abc import ABC, abstractmethod
 
 
-def instantiate_model(method):
+def instantiate_model(method = 'default',idios = {}):
     if method == 'lgbm':
-        return lgbm_model_wrapper.LGBMModel()
+        return lgbm_model_wrapper.LGBMModel(**idios)
     if method == 'arima':
-        return arima_model_wrapper.ArimaModel()
-
+        return arima_model_wrapper.ArimaModel(**idios)
+    if method == 'sma':
+        return sma_model_wrapper.SmaModel(**idios)
 
 
 class AbstractForecasterWrapper(ABC):
