@@ -65,8 +65,8 @@ def pair_handling_message(fetcher, msg, compute_minute_signal=True, compute_day_
                                  day_low_dict[key_day_ts],
                                  day_close_dict[key_day_ts], day_volu_dict[key_day_ts]]
             day_new_data = np.array(day_new_data_lst)
-            print('new daily data')
-            print(day_new_data)
+            #print('new daily data')
+            #print(day_new_data)
             if fetcher.day_np is None:
                 fetcher.day_np = day_new_data
             else:
@@ -128,8 +128,8 @@ def pair_handling_message(fetcher, msg, compute_minute_signal=True, compute_day_
             hour_new_data_lst = [key_hour_ts, hour_open_dict[key_hour_ts], hour_high_dict[key_hour_ts], hour_low_dict[key_hour_ts],
                             hour_close_dict[key_hour_ts], hour_volu_dict[key_hour_ts]]
             hour_new_data = np.array(hour_new_data_lst)
-
-            print(hour_new_data)
+            #print('new hour data')
+            #print(hour_new_data)
             if fetcher.hour_np is None:
                 fetcher.hour_np = hour_new_data
             else:
@@ -178,8 +178,8 @@ def pair_handling_message(fetcher, msg, compute_minute_signal=True, compute_day_
             new_data_lst = [key_ts, open_dict[key_ts], high_dict[key_ts], low_dict[key_ts],
                             close_dict[key_ts], volu_dict[key_ts]]
             new_data = np.array(new_data_lst)
-
-            print(new_data)
+            #print('new minute data')
+            #print(new_data)
             if fetcher.minute_np is None:
                 fetcher.minute_np = new_data
             else:
